/*****************************************************/
/* This file can be used on the original CCES data   */
/* to get the data set from Klingler and    	     */
/* Chatagnier's "Are You Doing Your Part? Veterans'  */
/* Political Attitudes, and Heinlein's Conception of */
/* Citizenship" published 2013 in Armed Forces &     */
/* Society. Requires downloading the file,	     */
/* CCES_2006_CommonContent.dta from		     */
/* http://projects.iq.harvard.edu/cces/data	     */
/*****************************************************/

set mem 200M
use "~\CCES_2006_CommonContent.dta ", clear

/* Create variable for veteran status */

g veteran = 1 if v3083 == 1
replace veteran = 0 if veteran == .

/* Create variable for definite volunteers (i.e., all female veterans and male veterans born after 1953) */

g vol = 1 if veteran == 1 & v2020 > 1953
replace vol = 1 if veteran == 1 & v2004 == 2
replace vol = 0 if vol == .

/* Create variable for current military service */

g current = 1 if v3081 == 1
replace current = 0 if current == .

/* Create easy names for demographic and other variables */

g age = 2006 - v2020

g male = v2004
replace male = 0 if male == 2 /* Female is coded as 2 in regular set */

g white = v2005
replace white = 0 if v2005 > 1

g black = 1 if v2005 == 2
replace black = 0 if black == .

g education = v2018 /* Higher numbers indicate more education (categorical) */

g married = v2019
replace married = 0 if married > 1

g church = v2026 /* Frequency DECREASING in number (may want to change) */
replace church = . if v2026 == 5 /* Eliminate "not sure" */

g income = v2032
replace income = . if income == 15 /* Get rid of prefer not to say */

g noncitizen = 1 if v3086 == 2 | v3086 == .

/* We only care about the electorate, so get rid of non-citizens */

drop if noncitizen == 1

/* Create easy names for roll call vote questions */

g partialbirth = 1 if v3060 == 1
replace partialbirth = 0 if v3060 == 2 /* Would R vote to ban partial birth abortion */

g fundstemcell = 1 if v3063 == 1
replace fundstemcell = 0 if v3063 == 2 /* Would R vote for fed. funding of stem cell research */

g citizenship = 1 if v3069 == 1
replace citizenship = 0 if v3069 == 2 /* Would R vote to give illegals a path to citizenship */

g iraqtimetable = 1 if v3066 == 1
replace iraqtimetable = 0 if v3066 == 2 /* Would R vote to set a time table for withdrawal */

g minwagevote = 1 if v3072 == 1
replace minwagevote = 0 if v3072 == 2 /* Would R vote to raise min. wage */

g capitalgains = 1 if v3075 == 1
replace capitalgains = 0 if v3075 == 2 /* Would R vote to extend CG tax cuts */

g cafta = 1 if v3078 == 1
replace cafta = 0 if v3078 == 2 /* Would R vote for CAFTA */

/* Create easy names for support of military force */
g oil = v3029
replace oil = 0 if oil == 2

g terrcamp = v3030
replace terrcamp = 0 if terrcamp == 2

g genocide = v3031
replace genocide = 0 if genocide == 2

g democracy = v3032
replace democracy = 0 if democracy == 2

g allies = v3033
replace allies = 0 if allies == 2

g un = v3034
replace un = 0 if un == 2

g never = v3035
replace never = 0 if never == 2

/* Keep only the variables relevant to this analysis */

keep veteran vol current age male white black education married church income ///
partialbirth fundstemcell citizenship iraqtimetable minwagevote capitalgains ///
cafta oil terrcamp genocide democracy allies un never

/* Save the data for use with the R file */

save "~\aydypreplicationdata.dta", replace
